import Anki from "ankisync";
import { R2rLocal } from ".";
import { ICondOptions, IEntry, IPagedOutput, IRender, ISortedData } from "./util";
export declare abstract class R2rFormat {
    abstract build(): Promise<this>;
    abstract close(): Promise<this>;
    abstract reset(): Promise<this>;
    abstract parseCond(q: string, options: ICondOptions<IEntry>): Promise<IPagedOutput<Partial<IEntry>>>;
    abstract insertMany(entries: IEntry[]): Promise<string[]>;
    abstract updateMany(ids: string[], u: Partial<IEntry>): Promise<void>;
    abstract addTags(ids: string[], tags: string[]): Promise<void>;
    abstract removeTags(ids: string[], tags: string[]): Promise<void>;
    abstract deleteMany(ids: string[]): Promise<void>;
    abstract render(cardId: string): Promise<IRender>;
    abstract getMedia(h: string): Promise<ArrayBuffer | null>;
    abstract fromR2r<T extends R2rLocal>(r2r: T, options?: {
        filename?: string;
        callback?: (p: IProgress) => void;
    }): Promise<void>;
    abstract export<T extends R2rLocal>(r2r: T, q: string, options?: {
        callback?: (p: IProgress) => void;
    }): Promise<void>;
    abstract fromAnki(anki: Anki, options?: {
        filename?: string;
        callback?: (p: IProgress) => void;
    }): Promise<void>;
    protected abstract updateSrsLevel(dSrsLevel: number, cardId: string): Promise<void>;
    protected abstract transformCreateOrUpdate(cardId: string | null, u: Partial<IEntry>, timestamp: Date): Promise<Partial<IEntry>>;
    protected abstract getOrCreateDeck(name: string): Promise<number>;
    protected abstract getData(cardId: string): Promise<ISortedData | null>;
    protected abstract getFront(cardId: string): Promise<string>;
    fromSortedData(sd: ISortedData): {
        data: Record<string, any>;
        order: Record<string, number>;
    };
    toSortedData(d: {
        data: Record<string, any>;
        order: Record<string, number>;
    }): ISortedData;
    markRight(cardId: string): Promise<void>;
    markWrong(cardId: string): Promise<void>;
    getTemplateKey(t: any): string;
    getNoteKey(data: Record<string, any>): string;
}
export interface IProgress {
    text: string;
    current?: number;
    max?: number;
}
